/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.field;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.geoviewer.Category;
import nl.cloudfarming.client.geoviewer.ObjectLayer;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.model.DataProvider;
import nl.cloudfarming.client.model.PartField;

/**
 * A Layer for fields of a specific year
 * @author Timon Veenstra
 */
public class PartFieldLayer extends ObjectLayer<PartFieldLayerObject> {

    private final Date date;

    public PartFieldLayer(final String nodeName, final Date date, final DataProvider dataProvider) {
        super(new PartFieldPalette(), Category.AREA, nodeName, dataProvider,true);
        this.date = date;
        if (getObjects().size() > 0) {
            clearObjects();
        }

        List<PartFieldLayerObject> objects = new ArrayList<PartFieldLayerObject>();

        CommonModelService service = new FieldAreaService();
        for (PartField field : service.findPartFieldsByDate(this.date)) {
            objects.add(new PartFieldLayerObject(field));
        }
        addObjects(objects);
    }
}
