/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.field.explorer;

import java.beans.IntrospectionException;
import java.util.List;
import nl.cloudfarming.client.area.AreaEventKey;
import nl.cloudfarming.client.area.AreaService;
import nl.cloudfarming.client.area.field.AreaFieldModule;
import nl.cloudfarming.client.area.field.FieldAreaService;
import nl.cloudfarming.client.area.field.HelpLineLayer;
import nl.cloudfarming.client.area.field.HelpLineLayerObject;
import nl.cloudfarming.client.model.DataProviderImpl;
import nl.cloudfarming.client.model.HelpLine;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventBus;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.Lookup;

/**
 *
 * @author Timon Veenstra
 */
public class HelpLineNodeFactory extends ChildFactory<HelpLine> {

    private AreaService service;
    private final HelpLineLayer layer;


    public HelpLineNodeFactory(HelpLineLayer layer) {
        this.layer = layer;
        GuiEventBus.addListener(new GuiEventListener() {

            @Override
            public void onEvent(GuiEvent event) {
                refresh(true);
            }

            @Override
            public boolean listensTo(GuiEventKey guiEventKey) {
                return guiEventKey.equals(AreaEventKey.IMPORT_SAVED) || guiEventKey.equals(AreaEventKey.HELP_LINE_REMOVED);
            }

            @Override
            public String getModuleName() {
                return AreaFieldModule.MODULE_NAME;
            }
        });
    }

    @Override
    protected Node createNodeForKey(HelpLine key) {
        try {
            HelpLineLayerObject layerObject = new HelpLineLayerObject(key);
            layer.addObject(layerObject);
            return new HelpLineNode(this.layer,layerObject, (DataProviderImpl)getService());
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    protected boolean createKeys(List<HelpLine> toPopulate) {
        toPopulate.addAll(getService().findAllHelpLines());
        return true;
    }

    public AreaService getService() {
        if (this.service == null) {
            this.service = Lookup.getDefault().lookup(AreaService.class);
        }
        return this.service;
    }

    public void setService(FieldAreaService service) {
        this.service = service;
    }
}
