/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.field.shape;

import nl.cloudfarming.client.area.field.PartFieldPalette;
import nl.cloudfarming.client.geoviewer.Category;
import nl.cloudfarming.client.geoviewer.LayerAction;
import nl.cloudfarming.client.geoviewer.ObjectLayer;
import nl.cloudfarming.client.model.ShapeFile;

/**
 * The importLayer containes shapes from an imported shapefile.
 * The layername is based on the filename of the imported shapefile and so it
 * is intended that each imported shapefile gets placed on a separate layer.
 *
 * The importlayer defines actions for (for example but not exclusive) saving the shapes to
 * more permanent layers.
 *
 * @author Timon Veenstra
 */
public class ImportLayer extends ObjectLayer<Shape> {

    private final ShapeFile shapeFile;

    public ImportLayer(final ShapeFile shapeFile, final ImportDataProvider dataProvider) {
        super(new PartFieldPalette(), Category.AREA, shapeFile.getFileName(), dataProvider, true);
        this.shapeFile = shapeFile;
    }

    /**
     * Return the shapeFile represented by this importlayer
     * @return The shapeFile represented by this importlayer
     */
    final public ShapeFile getShapeFile() {
        return shapeFile;
    }

    @Override
    public LayerAction[] getActions() {
        return new LayerAction[]{new SaveImportLayerAction(), new MarkAllShapesAsAction()};
    }
    
}
